AccountValid class
Annotations
@JsonSerializable.new(explicitToJson: true)
Properties
anyMap
→ bool ?
If true, Map types are not assumed to be Map <String, dynamic>
– which is the default type of Map instances return by JSON decode in
dart:convert.
final inherited
checked
→ bool ?
If true, generated fromJson functions include extra checks to validate
proper deserialization of types.
final inherited
constructor
→ String ?
Specifies a named constructor to target when creating the fromJson
function.
final inherited
converters
→ List <JsonConverter > ?
A list of JsonConverter to apply to this class.
final inherited
createFactory
→ bool ?
If true (the default), a private, static _$ExampleFromJson method
is created in the generated part file.
final inherited
createFieldMap
→ bool ?
If true (defaults to false), a private, static _$ExampleJsonMeta
constant is created in the generated part file.
final inherited
createJsonKeys
→ bool ?
If true (defaults to false), a private class _$ExampleJsonKeys
class is created in the generated part file.
final inherited
createJsonSchema
→ bool ?
If true (defaults to false), a top-level constant _$ExampleJsonSchema
will be created in the generated part file.
final inherited
createPerFieldToJson
→ bool ?
If true (defaults to false), a private, static _$ExamplePerFieldToJson
abstract class will be generated in the part file.
final inherited
createToJson
→ bool ?
If true (the default), A top-level function is created that you can
reference from your class.
final inherited
dateTimeUtc
→ bool ?
Whether the generator should use UTC time for DateTime fields.
final inherited
disallowUnrecognizedKeys
→ bool ?
If false (the default), then the generated FromJson function will
ignore unrecognized keys in the provided JSON Map .
final inherited
explicitToJson
→ bool ?
If true, generated toJson methods will explicitly call toJson on
nested objects.
final inherited
fieldRename
→ FieldRename?
Defines the automatic naming strategy when converting class field names
into JSON map keys.
final inherited
genericArgumentFactories
→ bool ?
When true on classes with type parameters (generic types), extra
"helper" parameters will be generated for fromJson and/or toJson to
support serializing values of those types.
final inherited
hashCode
→ int
The hash code for this object.
no setter inherited
ignoreUnannotated
→ bool ?
When true, only fields annotated with JsonKey will have code
generated.
final inherited
includeIfNull
→ bool ?
Whether the generator should include fields with null values in the
serialized output.
final inherited
isValid
↔ bool ?
getter/setter pair
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
Methods
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson ()
→ Map <String , dynamic >
toString ()
→ String
A string representation of this object.
inherited
withDefaults ()
→ JsonSerializable
Returns a new JsonSerializable instance with fields equal to the
corresponding values in this, if not null.
inherited