VcAuditSubmitReq class

Annotations
  • @JsonSerializable.new()

Constructors

VcAuditSubmitReq({String? payloadId, String? signPayload, String? signBcTxBlob, String? publicKey, int? border})
VcAuditSubmitReq.fromJson(Map<String, dynamic> json)
factory

Properties

border int?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
payloadId String?
getter/setter pair
publicKey String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signBcTxBlob String?
getter/setter pair
signPayload String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJsonModel(Map<String, dynamic> json) VcAuditSubmitReq